Class: Aws::MarketplaceCatalog::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MarketplaceCatalog::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-marketplacecatalog/client.rb,
sig/client.rbs
Overview
An API client for MarketplaceCatalog. To construct a client, you need to configure a :region and :credentials.
client = Aws::MarketplaceCatalog::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchDescribeEntitiesResponseSuccess, _CancelChangeSetResponseSuccess, _DeleteResourcePolicyResponseSuccess, _DescribeChangeSetResponseSuccess, _DescribeEntityResponseSuccess, _GetResourcePolicyResponseSuccess, _ListChangeSetsResponseSuccess, _ListEntitiesResponseSuccess, _ListTagsForResourceResponseSuccess, _PutResourcePolicyResponseSuccess, _StartChangeSetResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_describe_entities(params = {}) ⇒ Types::BatchDescribeEntitiesResponse
Returns metadata and content for multiple entities.
-
#cancel_change_set(params = {}) ⇒ Types::CancelChangeSetResponse
Used to cancel an open change request.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource-based policy on an entity that is identified by its resource ARN.
-
#describe_change_set(params = {}) ⇒ Types::DescribeChangeSetResponse
Provides information about a given change set.
-
#describe_entity(params = {}) ⇒ Types::DescribeEntityResponse
Returns the metadata and content of the entity.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Gets a resource-based policy of an entity that is identified by its resource ARN.
-
#list_change_sets(params = {}) ⇒ Types::ListChangeSetsResponse
Returns the list of change sets owned by the account being used to make the call.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Provides the list of entities of a given type.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags that have been added to a resource (either an [entity][1] or [change set][2]).
-
#put_resource_policy(params = {}) ⇒ Struct
Attaches a resource-based policy to an entity.
-
#start_change_set(params = {}) ⇒ Types::StartChangeSetResponse
Allows you to request changes for your entities.
-
#tag_resource(params = {}) ⇒ Struct
Tags a resource (either an [entity][1] or [change set][2]).
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag or list of tags from a resource (either an [entity][1] or [change set][2]).
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1479 1480 1481 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1479 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1482 1483 1484 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1482 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_describe_entities(params = {}) ⇒ Types::BatchDescribeEntitiesResponse
Returns metadata and content for multiple entities. This is the Batch
version of the DescribeEntity API and uses the same IAM permission
action as DescribeEntity API.
87 |
# File 'sig/client.rbs', line 87
def batch_describe_entities: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1452 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MarketplaceCatalog') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-marketplacecatalog' context[:gem_version] = '1.83.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_change_set(params = {}) ⇒ Types::CancelChangeSetResponse
Used to cancel an open change request. Must be sent before the status
of the request changes to APPLYING, the final stage of completing
your change request. You can describe a change during the 60-day
request history retention period for API calls.
103 |
# File 'sig/client.rbs', line 103
def cancel_change_set: (
|
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource-based policy on an entity that is identified by its resource ARN.
113 |
# File 'sig/client.rbs', line 113
def delete_resource_policy: (
|
#describe_change_set(params = {}) ⇒ Types::DescribeChangeSetResponse
Provides information about a given change set.
132 |
# File 'sig/client.rbs', line 132
def describe_change_set: (
|
#describe_entity(params = {}) ⇒ Types::DescribeEntityResponse
Returns the metadata and content of the entity.
148 |
# File 'sig/client.rbs', line 148
def describe_entity: (
|
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Gets a resource-based policy of an entity that is identified by its resource ARN.
159 |
# File 'sig/client.rbs', line 159
def get_resource_policy: (
|
#list_change_sets(params = {}) ⇒ Types::ListChangeSetsResponse
Returns the list of change sets owned by the account being used to
make the call. You can filter this list by providing any combination
of entityId, ChangeSetName, and status. If you provide more than
one filter, the API operation applies a logical AND between the
filters.
You can describe a change during the 60-day request history retention period for API calls.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
170 |
# File 'sig/client.rbs', line 170
def list_change_sets: (
|
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Provides the list of entities of a given type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
193 |
# File 'sig/client.rbs', line 193
def list_entities: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags that have been added to a resource (either an entity or change set).
489 |
# File 'sig/client.rbs', line 489
def list_tags_for_resource: (
|
#put_resource_policy(params = {}) ⇒ Struct
Attaches a resource-based policy to an entity. Examples of an entity
include: AmiProduct and ContainerProduct.
498 |
# File 'sig/client.rbs', line 498
def put_resource_policy: (
|
#start_change_set(params = {}) ⇒ Types::StartChangeSetResponse
Allows you to request changes for your entities. Within a single
ChangeSet, you can't start the same change type against the same
entity multiple times. Additionally, when a ChangeSet is running,
all the entities targeted by the different changes are locked until
the change set has completed (either succeeded, cancelled, or failed).
If you try to start a change set containing a change against an entity
that is already locked, you will receive a ResourceInUseException
error.
For example, you can't start the ChangeSet described in the
example later in this topic because it contains two changes to
run the same change type (AddRevisions) against the same entity
(entity-id@1).
For more information about working with change sets, see Working with change sets. For information about change types for single-AMI products, see Working with single-AMI products. Also, for more information about change types available for container-based products, see Working with container products.
To download "DetailsDocument" shapes, see Python and Java shapes on GitHub.
510 |
# File 'sig/client.rbs', line 510
def start_change_set: (
|
#tag_resource(params = {}) ⇒ Struct
Tags a resource (either an entity or change set).
547 |
# File 'sig/client.rbs', line 547
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag or list of tags from a resource (either an entity or change set).
562 |
# File 'sig/client.rbs', line 562
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1472 1473 1474 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1472 def waiter_names [] end |