Class: Aws::MarketplaceCatalog::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MarketplaceCatalog::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-marketplacecatalog/client.rb
Overview
An API client for MarketplaceCatalog. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MarketplaceCatalog::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_describe_entities(params = {}) ⇒ Types::BatchDescribeEntitiesResponse
Returns metadata and content for multiple entities.
-
#cancel_change_set(params = {}) ⇒ Types::CancelChangeSetResponse
Used to cancel an open change request.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource-based policy on an entity that is identified by its resource ARN.
-
#describe_change_set(params = {}) ⇒ Types::DescribeChangeSetResponse
Provides information about a given change set.
-
#describe_entity(params = {}) ⇒ Types::DescribeEntityResponse
Returns the metadata and content of the entity.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Gets a resource-based policy of an entity that is identified by its resource ARN.
-
#list_change_sets(params = {}) ⇒ Types::ListChangeSetsResponse
Returns the list of change sets owned by the account being used to make the call.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Provides the list of entities of a given type.
- #list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
-
#put_resource_policy(params = {}) ⇒ Struct
Attaches a resource-based policy to an entity.
-
#start_change_set(params = {}) ⇒ Types::StartChangeSetResponse
Allows you to request changes for your entities.
- #tag_resource(params = {}) ⇒ Struct
- #untag_resource(params = {}) ⇒ Struct
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
466 467 468 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 466 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1415 1416 1417 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1415 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1418 1419 1420 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1418 def errors_module Errors end |
Instance Method Details
#batch_describe_entities(params = {}) ⇒ Types::BatchDescribeEntitiesResponse
Returns metadata and content for multiple entities. This is the Batch version of the ‘DescribeEntity` API and uses the same IAM permission action as `DescribeEntity` API.
510 511 512 513 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 510 def batch_describe_entities(params = {}, = {}) req = build_request(:batch_describe_entities, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1388 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MarketplaceCatalog') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-marketplacecatalog' context[:gem_version] = '1.61.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_change_set(params = {}) ⇒ Types::CancelChangeSetResponse
Used to cancel an open change request. Must be sent before the status of the request changes to ‘APPLYING`, the final stage of completing your change request. You can describe a change during the 60-day request history retention period for API calls.
549 550 551 552 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 549 def cancel_change_set(params = {}, = {}) req = build_request(:cancel_change_set, params) req.send_request() end |
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource-based policy on an entity that is identified by its resource ARN.
573 574 575 576 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 573 def delete_resource_policy(params = {}, = {}) req = build_request(:delete_resource_policy, params) req.send_request() end |
#describe_change_set(params = {}) ⇒ Types::DescribeChangeSetResponse
Provides information about a given change set.
633 634 635 636 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 633 def describe_change_set(params = {}, = {}) req = build_request(:describe_change_set, params) req.send_request() end |
#describe_entity(params = {}) ⇒ Types::DescribeEntityResponse
Returns the metadata and content of the entity.
675 676 677 678 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 675 def describe_entity(params = {}, = {}) req = build_request(:describe_entity, params) req.send_request() end |
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Gets a resource-based policy of an entity that is identified by its resource ARN.
705 706 707 708 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 705 def get_resource_policy(params = {}, = {}) req = build_request(:get_resource_policy, params) req.send_request() end |
#list_change_sets(params = {}) ⇒ Types::ListChangeSetsResponse
Returns the list of change sets owned by the account being used to make the call. You can filter this list by providing any combination of ‘entityId`, `ChangeSetName`, and status. If you provide more than one filter, the API operation applies a logical AND between the filters.
You can describe a change during the 60-day request history retention period for API calls.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
780 781 782 783 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 780 def list_change_sets(params = {}, = {}) req = build_request(:list_change_sets, params) req.send_request() end |
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Provides the list of entities of a given type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1125 1126 1127 1128 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1125 def list_entities(params = {}, = {}) req = build_request(:list_entities, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags that have been added to a resource (either an
- entity][1
-
or [change set]).
[1]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#catalog-api-entities [2]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets
1164 1165 1166 1167 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1164 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_resource_policy(params = {}) ⇒ Struct
Attaches a resource-based policy to an entity. Examples of an entity include: ‘AmiProduct` and `ContainerProduct`.
1192 1193 1194 1195 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1192 def put_resource_policy(params = {}, = {}) req = build_request(:put_resource_policy, params) req.send_request() end |
#start_change_set(params = {}) ⇒ Types::StartChangeSetResponse
Allows you to request changes for your entities. Within a single ‘ChangeSet`, you can’t start the same change type against the same entity multiple times. Additionally, when a ‘ChangeSet` is running, all the entities targeted by the different changes are locked until the change set has completed (either succeeded, cancelled, or failed). If you try to start a change set containing a change against an entity that is already locked, you will receive a `ResourceInUseException` error.
For example, you can’t start the ‘ChangeSet` described in the
- example][1
-
later in this topic because it contains two changes to
run the same change type (‘AddRevisions`) against the same entity (`entity-id@1`).
For more information about working with change sets, see [ Working with change sets]. For information about change types for single-AMI products, see [Working with single-AMI products]. Also, for more information about change types available for container-based products, see [Working with container products].
To download “DetailsDocument” shapes, see [Python] and [Java] shapes on GitHub.
[1]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_StartChangeSet.html#API_StartChangeSet_Examples [2]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets [3]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/ami-products.html#working-with-single-AMI-products [4]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/container-products.html#working-with-container-products [5]: github.com/awslabs/aws-marketplace-catalog-api-shapes-for-python [6]: github.com/awslabs/aws-marketplace-catalog-api-shapes-for-java/tree/main
1307 1308 1309 1310 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1307 def start_change_set(params = {}, = {}) req = build_request(:start_change_set, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tags a resource (either an [entity] or [change set]).
[1]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#catalog-api-entities [2]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets
1345 1346 1347 1348 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1345 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag or list of tags from a resource (either an [entity] or [change set]).
[1]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#catalog-api-entities [2]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets
1379 1380 1381 1382 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1379 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1408 1409 1410 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1408 def waiter_names [] end |