Class: Aws::MarketplaceCatalog::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MarketplaceCatalog::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-marketplacecatalog/client.rb
Overview
An API client for MarketplaceCatalog. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MarketplaceCatalog::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_describe_entities(params = {}) ⇒ Types::BatchDescribeEntitiesResponse
Returns metadata and content for multiple entities.
-
#cancel_change_set(params = {}) ⇒ Types::CancelChangeSetResponse
Used to cancel an open change request.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource-based policy on an entity that is identified by its resource ARN.
-
#describe_change_set(params = {}) ⇒ Types::DescribeChangeSetResponse
Provides information about a given change set.
-
#describe_entity(params = {}) ⇒ Types::DescribeEntityResponse
Returns the metadata and content of the entity.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Gets a resource-based policy of an entity that is identified by its resource ARN.
-
#list_change_sets(params = {}) ⇒ Types::ListChangeSetsResponse
Returns the list of change sets owned by the account being used to make the call.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Provides the list of entities of a given type.
- #list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
-
#put_resource_policy(params = {}) ⇒ Struct
Attaches a resource-based policy to an entity.
-
#start_change_set(params = {}) ⇒ Types::StartChangeSetResponse
Allows you to request changes for your entities.
- #tag_resource(params = {}) ⇒ Struct
- #untag_resource(params = {}) ⇒ Struct
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
446 447 448 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 446 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1366 1367 1368 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1366 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1369 1370 1371 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1369 def errors_module Errors end |
Instance Method Details
#batch_describe_entities(params = {}) ⇒ Types::BatchDescribeEntitiesResponse
Returns metadata and content for multiple entities. This is the Batch version of the ‘DescribeEntity` API and uses the same IAM permission action as `DescribeEntity` API.
490 491 492 493 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 490 def batch_describe_entities(params = {}, = {}) req = build_request(:batch_describe_entities, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1339 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MarketplaceCatalog') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-marketplacecatalog' context[:gem_version] = '1.51.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_change_set(params = {}) ⇒ Types::CancelChangeSetResponse
Used to cancel an open change request. Must be sent before the status of the request changes to ‘APPLYING`, the final stage of completing your change request. You can describe a change during the 60-day request history retention period for API calls.
529 530 531 532 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 529 def cancel_change_set(params = {}, = {}) req = build_request(:cancel_change_set, params) req.send_request() end |
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource-based policy on an entity that is identified by its resource ARN.
553 554 555 556 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 553 def delete_resource_policy(params = {}, = {}) req = build_request(:delete_resource_policy, params) req.send_request() end |
#describe_change_set(params = {}) ⇒ Types::DescribeChangeSetResponse
Provides information about a given change set.
613 614 615 616 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 613 def describe_change_set(params = {}, = {}) req = build_request(:describe_change_set, params) req.send_request() end |
#describe_entity(params = {}) ⇒ Types::DescribeEntityResponse
Returns the metadata and content of the entity.
655 656 657 658 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 655 def describe_entity(params = {}, = {}) req = build_request(:describe_entity, params) req.send_request() end |
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Gets a resource-based policy of an entity that is identified by its resource ARN.
685 686 687 688 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 685 def get_resource_policy(params = {}, = {}) req = build_request(:get_resource_policy, params) req.send_request() end |
#list_change_sets(params = {}) ⇒ Types::ListChangeSetsResponse
Returns the list of change sets owned by the account being used to make the call. You can filter this list by providing any combination of ‘entityId`, `ChangeSetName`, and status. If you provide more than one filter, the API operation applies a logical AND between the filters.
You can describe a change during the 60-day request history retention period for API calls.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
760 761 762 763 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 760 def list_change_sets(params = {}, = {}) req = build_request(:list_change_sets, params) req.send_request() end |
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Provides the list of entities of a given type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1081 1082 1083 1084 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1081 def list_entities(params = {}, = {}) req = build_request(:list_entities, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags that have been added to a resource (either an
- entity][1
-
or [change set]).
[1]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#catalog-api-entities [2]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets
1120 1121 1122 1123 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1120 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_resource_policy(params = {}) ⇒ Struct
Attaches a resource-based policy to an entity. Examples of an entity include: ‘AmiProduct` and `ContainerProduct`.
1148 1149 1150 1151 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1148 def put_resource_policy(params = {}, = {}) req = build_request(:put_resource_policy, params) req.send_request() end |
#start_change_set(params = {}) ⇒ Types::StartChangeSetResponse
Allows you to request changes for your entities. Within a single ‘ChangeSet`, you can’t start the same change type against the same entity multiple times. Additionally, when a ‘ChangeSet` is running, all the entities targeted by the different changes are locked until the change set has completed (either succeeded, cancelled, or failed). If you try to start a change set containing a change against an entity that is already locked, you will receive a `ResourceInUseException` error.
For example, you can’t start the ‘ChangeSet` described in the
- example][1
-
later in this topic because it contains two changes to
run the same change type (‘AddRevisions`) against the same entity (`entity-id@1`).
For more information about working with change sets, see [ Working with change sets]. For information about change types for single-AMI products, see [Working with single-AMI products]. Also, for more information about change types available for container-based products, see [Working with container products].
[1]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_StartChangeSet.html#API_StartChangeSet_Examples [2]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets [3]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/ami-products.html#working-with-single-AMI-products [4]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/container-products.html#working-with-container-products
1258 1259 1260 1261 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1258 def start_change_set(params = {}, = {}) req = build_request(:start_change_set, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tags a resource (either an [entity] or [change set]).
[1]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#catalog-api-entities [2]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets
1296 1297 1298 1299 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1296 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag or list of tags from a resource (either an [entity] or [change set]).
[1]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#catalog-api-entities [2]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets
1330 1331 1332 1333 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1330 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1359 1360 1361 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 1359 def waiter_names [] end |