Class: Aws::MarketplaceCatalog::Client

Inherits:
Seahorse::Client::Base
  • Object
show all
Includes:
ClientStubs
Defined in:
lib/aws-sdk-marketplacecatalog/client.rb

Overview

An API client for MarketplaceCatalog. To construct a client, you need to configure a `:region` and `:credentials`.

client = Aws::MarketplaceCatalog::Client.new(
  region: region_name,
  credentials: credentials,
  # ...
)

For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).

See #initialize for a full list of supported configuration options.

Class Attribute Summary collapse

API Operations collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ Client

Returns a new instance of Client.

Parameters:

  • options (Hash)

Options Hash (options):

  • :credentials (required, Aws::CredentialProvider)

    Your AWS credentials. This can be an instance of any one of the following classes:

    • `Aws::Credentials` - Used for configuring static, non-refreshing credentials.

    • `Aws::SharedCredentials` - Used for loading static credentials from a shared file, such as `~/.aws/config`.

    • `Aws::AssumeRoleCredentials` - Used when you need to assume a role.

    • `Aws::AssumeRoleWebIdentityCredentials` - Used when you need to assume a role after providing credentials via the web.

    • `Aws::SSOCredentials` - Used for loading credentials from AWS SSO using an access token generated from `aws login`.

    • `Aws::ProcessCredentials` - Used for loading credentials from a process that outputs to stdout.

    • `Aws::InstanceProfileCredentials` - Used for loading credentials from an EC2 IMDS on an EC2 instance.

    • `Aws::ECSCredentials` - Used for loading credentials from instances running in ECS.

    • `Aws::CognitoIdentityCredentials` - Used for loading credentials from the Cognito Identity service.

    When `:credentials` are not configured directly, the following locations will be searched for credentials:

    • `Aws.config`

    • The `:access_key_id`, `:secret_access_key`, and `:session_token` options.

    • ENV, ENV

    • `~/.aws/credentials`

    • `~/.aws/config`

    • EC2/ECS IMDS instance profile - When used by default, the timeouts are very aggressive. Construct and pass an instance of `Aws::InstanceProfileCredentails` or `Aws::ECSCredentials` to enable retries and extended timeouts. Instance profile credential fetching can be disabled by setting ENV to true.

  • :region (required, String)

    The AWS region to connect to. The configured `:region` is used to determine the service `:endpoint`. When not passed, a default `:region` is searched for in the following locations:

  • :access_key_id (String)
  • :active_endpoint_cache (Boolean) — default: false

    When set to `true`, a thread polling for endpoints will be running in the background every 60 secs (default). Defaults to `false`.

  • :adaptive_retry_wait_to_fill (Boolean) — default: true

    Used only in `adaptive` retry mode. When true, the request will sleep until there is sufficent client side capacity to retry the request. When false, the request will raise a `RetryCapacityNotAvailableError` and will not retry instead of sleeping.

  • :client_side_monitoring (Boolean) — default: false

    When `true`, client-side metrics will be collected for all API requests from this client.

  • :client_side_monitoring_client_id (String) — default: ""

    Allows you to provide an identifier for this client which will be attached to all generated client side metrics. Defaults to an empty string.

  • :client_side_monitoring_host (String) — default: "127.0.0.1"

    Allows you to specify the DNS hostname or IPv4 or IPv6 address that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_port (Integer) — default: 31000

    Required for publishing client metrics. The port that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_publisher (Aws::ClientSideMonitoring::Publisher) — default: Aws::ClientSideMonitoring::Publisher

    Allows you to provide a custom client-side monitoring publisher class. By default, will use the Client Side Monitoring Agent Publisher.

  • :convert_params (Boolean) — default: true

    When `true`, an attempt is made to coerce request parameters into the required types.

  • :correct_clock_skew (Boolean) — default: true

    Used only in `standard` and adaptive retry modes. Specifies whether to apply a clock skew correction and retry requests with skewed client clocks.

  • :defaults_mode (String) — default: "legacy"

    See DefaultsModeConfiguration for a list of the accepted modes and the configuration defaults that are included.

  • :disable_host_prefix_injection (Boolean) — default: false

    Set to true to disable SDK automatically adding host prefix to default service endpoint when available.

  • :endpoint (String)

    The client endpoint is normally constructed from the `:region` option. You should only configure an `:endpoint` when connecting to test or custom endpoints. This should be a valid HTTP(S) URI.

  • :endpoint_cache_max_entries (Integer) — default: 1000

    Used for the maximum size limit of the LRU cache storing endpoints data for endpoint discovery enabled operations. Defaults to 1000.

  • :endpoint_cache_max_threads (Integer) — default: 10

    Used for the maximum threads in use for polling endpoints to be cached, defaults to 10.

  • :endpoint_cache_poll_interval (Integer) — default: 60

    When :endpoint_discovery and :active_endpoint_cache is enabled, Use this option to config the time interval in seconds for making requests fetching endpoints information. Defaults to 60 sec.

  • :endpoint_discovery (Boolean) — default: false

    When set to `true`, endpoint discovery will be enabled for operations when available.

  • :log_formatter (Aws::Log::Formatter) — default: Aws::Log::Formatter.default

    The log formatter.

  • :log_level (Symbol) — default: :info

    The log level to send messages to the `:logger` at.

  • :logger (Logger)

    The Logger instance to send log messages to. If this option is not set, logging will be disabled.

  • :max_attempts (Integer) — default: 3

    An integer representing the maximum number attempts that will be made for a single request, including the initial attempt. For example, setting this value to 5 will result in a request being retried up to 4 times. Used in `standard` and `adaptive` retry modes.

  • :profile (String) — default: "default"

    Used when loading credentials from the shared credentials file at HOME/.aws/credentials. When not specified, 'default' is used.

  • :retry_backoff (Proc)

    A proc or lambda used for backoff. Defaults to 2**retries * retry_base_delay. This option is only used in the `legacy` retry mode.

  • :retry_base_delay (Float) — default: 0.3

    The base delay in seconds used by the default backoff function. This option is only used in the `legacy` retry mode.

  • :retry_jitter (Symbol) — default: :none

    A delay randomiser function used by the default backoff function. Some predefined functions can be referenced by name - :none, :equal, :full, otherwise a Proc that takes and returns a number. This option is only used in the `legacy` retry mode.

    @see www.awsarchitectureblog.com/2015/03/backoff.html

  • :retry_limit (Integer) — default: 3

    The maximum number of times to retry failed requests. Only ~ 500 level server errors and certain ~ 400 level client errors are retried. Generally, these are throttling errors, data checksum errors, networking errors, timeout errors, auth errors, endpoint discovery, and errors from expired credentials. This option is only used in the `legacy` retry mode.

  • :retry_max_delay (Integer) — default: 0

    The maximum number of seconds to delay between retries (0 for no limit) used by the default backoff function. This option is only used in the `legacy` retry mode.

  • :retry_mode (String) — default: "legacy"

    Specifies which retry algorithm to use. Values are:

    • `legacy` - The pre-existing retry behavior. This is default value if no retry mode is provided.

    • `standard` - A standardized set of retry rules across the AWS SDKs. This includes support for retry quotas, which limit the number of unsuccessful retries a client can make.

    • `adaptive` - An experimental retry mode that includes all the functionality of `standard` mode along with automatic client side throttling. This is a provisional mode that may change behavior in the future.

  • :secret_access_key (String)
  • :session_token (String)
  • :stub_responses (Boolean) — default: false

    Causes the client to return stubbed responses. By default fake responses are generated and returned. You can specify the response data to return or errors to raise by calling ClientStubs#stub_responses. See ClientStubs for more information.

    ** Please note ** When response stubbing is enabled, no HTTP requests are made, and retries are disabled.

  • :token_provider (Aws::TokenProvider)

    A Bearer Token Provider. This can be an instance of any one of the following classes:

    • `Aws::StaticTokenProvider` - Used for configuring static, non-refreshing tokens.

    • `Aws::SSOTokenProvider` - Used for loading tokens from AWS SSO using an access token generated from `aws login`.

    When `:token_provider` is not configured directly, the `Aws::TokenProviderChain` will be used to search for tokens configured for your profile in shared configuration files.

  • :use_dualstack_endpoint (Boolean)

    When set to `true`, dualstack enabled endpoints (with `.aws` TLD) will be used if available.

  • :use_fips_endpoint (Boolean)

    When set to `true`, fips compatible endpoints will be used if available. When a `fips` region is used, the region is normalized and this config is set to `true`.

  • :validate_params (Boolean) — default: true

    When `true`, request parameters are validated before sending the request.

  • :endpoint_provider (Aws::MarketplaceCatalog::EndpointProvider)

    The endpoint provider used to resolve endpoints. Any object that responds to `#resolve_endpoint(parameters)` where `parameters` is a Struct similar to `Aws::MarketplaceCatalog::EndpointParameters`

  • :http_proxy (URI::HTTP, String)

    A proxy to send requests through. Formatted like 'proxy.com:123'.

  • :http_open_timeout (Float) — default: 15

    The number of seconds to wait when opening a HTTP session before raising a `Timeout::Error`.

  • :http_read_timeout (Float) — default: 60

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_idle_timeout (Float) — default: 5

    The number of seconds a connection is allowed to sit idle before it is considered stale. Stale connections are closed and removed from the pool before making a request.

  • :http_continue_timeout (Float) — default: 1

    The number of seconds to wait for a 100-continue response before sending the request body. This option has no effect unless the request has “Expect” header set to “100-continue”. Defaults to `nil` which disables this behaviour. This value can safely be set per request on the session.

  • :ssl_timeout (Float) — default: nil

    Sets the SSL timeout in seconds.

  • :http_wire_trace (Boolean) — default: false

    When `true`, HTTP debug output will be sent to the `:logger`.

  • :ssl_verify_peer (Boolean) — default: true

    When `true`, SSL peer certificates are verified when establishing a connection.

  • :ssl_ca_bundle (String)

    Full path to the SSL certificate authority bundle file that should be used when verifying peer certificates. If you do not pass `:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_directory (String)

    Full path of the directory that contains the unbundled SSL certificate authority files for verifying peer certificates. If you do not pass `:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.



365
366
367
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 365

def initialize(*args)
  super
end

Class Attribute Details

.identifierObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



882
883
884
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 882

def identifier
  @identifier
end

Class Method Details

.errors_moduleObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



885
886
887
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 885

def errors_module
  Errors
end

Instance Method Details

#build_request(operation_name, params = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • params ({}) (defaults to: {})


860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 860

def build_request(operation_name, params = {})
  handlers = @handlers.for(operation_name)
  context = Seahorse::Client::RequestContext.new(
    operation_name: operation_name,
    operation: config.api.operation(operation_name),
    client: self,
    params: params,
    config: config)
  context[:gem_name] = 'aws-sdk-marketplacecatalog'
  context[:gem_version] = '1.25.0'
  Seahorse::Client::Request.new(handlers, context)
end

#cancel_change_set(params = {}) ⇒ Types::CancelChangeSetResponse

Used to cancel an open change request. Must be sent before the status of the request changes to `APPLYING`, the final stage of completing your change request. You can describe a change during the 60-day request history retention period for API calls.

Examples:

Request syntax with placeholder values


resp = client.cancel_change_set({
  catalog: "Catalog", # required
  change_set_id: "ResourceId", # required
})

Response structure


resp.change_set_id #=> String
resp.change_set_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :catalog (required, String)

    Required. The catalog related to the request. Fixed value: `AWSMarketplace`.

  • :change_set_id (required, String)

    Required. The unique identifier of the `StartChangeSet` request that you want to cancel.

Returns:

See Also:



405
406
407
408
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 405

def cancel_change_set(params = {}, options = {})
  req = build_request(:cancel_change_set, params)
  req.send_request(options)
end

#describe_change_set(params = {}) ⇒ Types::DescribeChangeSetResponse

Provides information about a given change set.

Examples:

Request syntax with placeholder values


resp = client.describe_change_set({
  catalog: "Catalog", # required
  change_set_id: "ResourceId", # required
})

Response structure


resp.change_set_id #=> String
resp.change_set_arn #=> String
resp.change_set_name #=> String
resp.start_time #=> String
resp.end_time #=> String
resp.status #=> String, one of "PREPARING", "APPLYING", "SUCCEEDED", "CANCELLED", "FAILED"
resp.failure_code #=> String, one of "CLIENT_ERROR", "SERVER_FAULT"
resp.failure_description #=> String
resp.change_set #=> Array
resp.change_set[0].change_type #=> String
resp.change_set[0].entity.type #=> String
resp.change_set[0].entity.identifier #=> String
resp.change_set[0].details #=> String
resp.change_set[0].error_detail_list #=> Array
resp.change_set[0].error_detail_list[0].error_code #=> String
resp.change_set[0].error_detail_list[0].error_message #=> String
resp.change_set[0].change_name #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :catalog (required, String)

    Required. The catalog related to the request. Fixed value: `AWSMarketplace`

  • :change_set_id (required, String)

    Required. The unique identifier for the `StartChangeSet` request that you want to describe the details for.

Returns:

See Also:



463
464
465
466
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 463

def describe_change_set(params = {}, options = {})
  req = build_request(:describe_change_set, params)
  req.send_request(options)
end

#describe_entity(params = {}) ⇒ Types::DescribeEntityResponse

Returns the metadata and content of the entity.

Examples:

Request syntax with placeholder values


resp = client.describe_entity({
  catalog: "Catalog", # required
  entity_id: "ResourceId", # required
})

Response structure


resp.entity_type #=> String
resp.entity_identifier #=> String
resp.entity_arn #=> String
resp.last_modified_date #=> String
resp.details #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :catalog (required, String)

    Required. The catalog related to the request. Fixed value: `AWSMarketplace`

  • :entity_id (required, String)

    Required. The unique ID of the entity to describe.

Returns:

See Also:



504
505
506
507
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 504

def describe_entity(params = {}, options = {})
  req = build_request(:describe_entity, params)
  req.send_request(options)
end

#list_change_sets(params = {}) ⇒ Types::ListChangeSetsResponse

Returns the list of change sets owned by the account being used to make the call. You can filter this list by providing any combination of `entityId`, `ChangeSetName`, and status. If you provide more than one filter, the API operation applies a logical AND between the filters.

You can describe a change during the 60-day request history retention period for API calls.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_change_sets({
  catalog: "Catalog", # required
  filter_list: [
    {
      name: "FilterName",
      value_list: ["FilterValueContent"],
    },
  ],
  sort: {
    sort_by: "SortBy",
    sort_order: "ASCENDING", # accepts ASCENDING, DESCENDING
  },
  max_results: 1,
  next_token: "NextToken",
})

Response structure


resp.change_set_summary_list #=> Array
resp.change_set_summary_list[0].change_set_id #=> String
resp.change_set_summary_list[0].change_set_arn #=> String
resp.change_set_summary_list[0].change_set_name #=> String
resp.change_set_summary_list[0].start_time #=> String
resp.change_set_summary_list[0].end_time #=> String
resp.change_set_summary_list[0].status #=> String, one of "PREPARING", "APPLYING", "SUCCEEDED", "CANCELLED", "FAILED"
resp.change_set_summary_list[0].entity_id_list #=> Array
resp.change_set_summary_list[0].entity_id_list[0] #=> String
resp.change_set_summary_list[0].failure_code #=> String, one of "CLIENT_ERROR", "SERVER_FAULT"
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :catalog (required, String)

    The catalog related to the request. Fixed value: `AWSMarketplace`

  • :filter_list (Array<Types::Filter>)

    An array of filter objects.

  • :sort (Types::Sort)

    An object that contains two attributes, `SortBy` and `SortOrder`.

  • :max_results (Integer)

    The maximum number of results returned by a single call. This value must be provided in the next call to retrieve the next set of results. By default, this value is 20.

  • :next_token (String)

    The token value retrieved from a previous call to access the next page of results.

Returns:

See Also:



579
580
581
582
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 579

def list_change_sets(params = {}, options = {})
  req = build_request(:list_change_sets, params)
  req.send_request(options)
end

#list_entities(params = {}) ⇒ Types::ListEntitiesResponse

Provides the list of entities of a given type.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_entities({
  catalog: "Catalog", # required
  entity_type: "EntityType", # required
  filter_list: [
    {
      name: "FilterName",
      value_list: ["FilterValueContent"],
    },
  ],
  sort: {
    sort_by: "SortBy",
    sort_order: "ASCENDING", # accepts ASCENDING, DESCENDING
  },
  next_token: "NextToken",
  max_results: 1,
})

Response structure


resp.entity_summary_list #=> Array
resp.entity_summary_list[0].name #=> String
resp.entity_summary_list[0].entity_type #=> String
resp.entity_summary_list[0].entity_id #=> String
resp.entity_summary_list[0].entity_arn #=> String
resp.entity_summary_list[0].last_modified_date #=> String
resp.entity_summary_list[0].visibility #=> String
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :catalog (required, String)

    The catalog related to the request. Fixed value: `AWSMarketplace`

  • :entity_type (required, String)

    The type of entities to retrieve.

  • :filter_list (Array<Types::Filter>)

    An array of filter objects. Each filter object contains two attributes, `filterName` and `filterValues`.

  • :sort (Types::Sort)

    An object that contains two attributes, `SortBy` and `SortOrder`.

  • :next_token (String)

    The value of the next token, if it exists. Null if there are no more results.

  • :max_results (Integer)

    Specifies the upper limit of the elements on a single page. If a value isn't provided, the default value is 20.

Returns:

See Also:



648
649
650
651
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 648

def list_entities(params = {}, options = {})
  req = build_request(:list_entities, params)
  req.send_request(options)
end

#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse

Examples:

Request syntax with placeholder values


resp = client.list_tags_for_resource({
  resource_arn: "ResourceARN", # required
})

Response structure


resp.resource_arn #=> String
resp.tags #=> Array
resp.tags[0].key #=> String
resp.tags[0].value #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    Required. The Amazon Resource Name (ARN) associated with the resource you want to list tags on.

Returns:

See Also:



687
688
689
690
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 687

def list_tags_for_resource(params = {}, options = {})
  req = build_request(:list_tags_for_resource, params)
  req.send_request(options)
end

#start_change_set(params = {}) ⇒ Types::StartChangeSetResponse

Allows you to request changes for your entities. Within a single `ChangeSet`, you can't start the same change type against the same entity multiple times. Additionally, when a `ChangeSet` is running, all the entities targeted by the different changes are locked until the change set has completed (either succeeded, cancelled, or failed). If you try to start a change set containing a change against an entity that is already locked, you will receive a `ResourceInUseException` error.

For example, you can't start the `ChangeSet` described in the

example][1

later in this topic because it contains two changes to

run the same change type (`AddRevisions`) against the same entity (`entity-id@1`).

For more information about working with change sets, see [ Working with change sets].

[1]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_StartChangeSet.html#API_StartChangeSet_Examples [2]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets

Examples:

Request syntax with placeholder values


resp = client.start_change_set({
  catalog: "Catalog", # required
  change_set: [ # required
    {
      change_type: "ChangeType", # required
      entity: { # required
        type: "EntityType", # required
        identifier: "Identifier",
      },
      entity_tags: [
        {
          key: "TagKey", # required
          value: "TagValue", # required
        },
      ],
      details: "Json", # required
      change_name: "ChangeName",
    },
  ],
  change_set_name: "ChangeSetName",
  client_request_token: "ClientRequestToken",
  change_set_tags: [
    {
      key: "TagKey", # required
      value: "TagValue", # required
    },
  ],
})

Response structure


resp.change_set_id #=> String
resp.change_set_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :catalog (required, String)

    The catalog related to the request. Fixed value: `AWSMarketplace`

  • :change_set (required, Array<Types::Change>)

    Array of `change` object.

  • :change_set_name (String)

    Optional case sensitive string of up to 100 ASCII characters. The change set name can be used to filter the list of change sets.

  • :client_request_token (String)

    A unique token to identify the request to ensure idempotency.

    **A suitable default value is auto-generated.** You should normally not need to pass this option.**

  • :change_set_tags (Array<Types::Tag>)

    A list of objects specifying each key name and value for the `ChangeSetTags` property.

Returns:

See Also:



779
780
781
782
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 779

def start_change_set(params = {}, options = {})
  req = build_request(:start_change_set, params)
  req.send_request(options)
end

#tag_resource(params = {}) ⇒ Struct

Examples:

Request syntax with placeholder values


resp = client.tag_resource({
  resource_arn: "ResourceARN", # required
  tags: [ # required
    {
      key: "TagKey", # required
      value: "TagValue", # required
    },
  ],
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    Required. The Amazon Resource Name (ARN) associated with the resource you want to tag.

  • :tags (required, Array<Types::Tag>)

    Required. A list of objects specifying each key name and value. Number of objects allowed: 1-50.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



817
818
819
820
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 817

def tag_resource(params = {}, options = {})
  req = build_request(:tag_resource, params)
  req.send_request(options)
end

#untag_resource(params = {}) ⇒ Struct

Examples:

Request syntax with placeholder values


resp = client.untag_resource({
  resource_arn: "ResourceARN", # required
  tag_keys: ["TagKey"], # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    Required. The Amazon Resource Name (ARN) associated with the resource you want to remove the tag from.

  • :tag_keys (required, Array<String>)

    Required. A list of key names of tags to be removed. Number of strings allowed: 0-256.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



851
852
853
854
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 851

def untag_resource(params = {}, options = {})
  req = build_request(:untag_resource, params)
  req.send_request(options)
end

#waiter_namesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


875
876
877
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 875

def waiter_names
  []
end