Class: Aws::MarketplaceCatalog::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MarketplaceCatalog::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-marketplacecatalog/client.rb
Overview
An API client for MarketplaceCatalog. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::MarketplaceCatalog::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_change_set(params = {}) ⇒ Types::CancelChangeSetResponse
Used to cancel an open change request.
-
#describe_change_set(params = {}) ⇒ Types::DescribeChangeSetResponse
Provides information about a given change set.
-
#describe_entity(params = {}) ⇒ Types::DescribeEntityResponse
Returns the metadata and content of the entity.
-
#list_change_sets(params = {}) ⇒ Types::ListChangeSetsResponse
Returns the list of change sets owned by the account being used to make the call.
-
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Provides the list of entities of a given type.
-
#start_change_set(params = {}) ⇒ Types::StartChangeSetResponse
This operation allows you to request changes for your entities.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
365 366 367 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 365 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
754 755 756 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 754 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
757 758 759 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 757 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 732 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-marketplacecatalog' context[:gem_version] = '1.23.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_change_set(params = {}) ⇒ Types::CancelChangeSetResponse
Used to cancel an open change request. Must be sent before the status of the request changes to `APPLYING`, the final stage of completing your change request. You can describe a change during the 60-day request history retention period for API calls.
405 406 407 408 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 405 def cancel_change_set(params = {}, = {}) req = build_request(:cancel_change_set, params) req.send_request() end |
#describe_change_set(params = {}) ⇒ Types::DescribeChangeSetResponse
Provides information about a given change set.
463 464 465 466 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 463 def describe_change_set(params = {}, = {}) req = build_request(:describe_change_set, params) req.send_request() end |
#describe_entity(params = {}) ⇒ Types::DescribeEntityResponse
Returns the metadata and content of the entity.
504 505 506 507 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 504 def describe_entity(params = {}, = {}) req = build_request(:describe_entity, params) req.send_request() end |
#list_change_sets(params = {}) ⇒ Types::ListChangeSetsResponse
Returns the list of change sets owned by the account being used to make the call. You can filter this list by providing any combination of `entityId`, `ChangeSetName`, and status. If you provide more than one filter, the API operation applies a logical AND between the filters.
You can describe a change during the 60-day request history retention period for API calls.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
579 580 581 582 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 579 def list_change_sets(params = {}, = {}) req = build_request(:list_change_sets, params) req.send_request() end |
#list_entities(params = {}) ⇒ Types::ListEntitiesResponse
Provides the list of entities of a given type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
648 649 650 651 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 648 def list_entities(params = {}, = {}) req = build_request(:list_entities, params) req.send_request() end |
#start_change_set(params = {}) ⇒ Types::StartChangeSetResponse
This operation allows you to request changes for your entities. Within a single ChangeSet, you cannot start the same change type against the same entity multiple times. Additionally, when a ChangeSet is running, all the entities targeted by the different changes are locked until the ChangeSet has completed (either succeeded, cancelled, or failed). If you try to start a ChangeSet containing a change against an entity that is already locked, you will receive a `ResourceInUseException`.
For example, you cannot start the ChangeSet described in the
- example][1
-
later in this topic, because it contains two changes to
execute the same change type (`AddRevisions`) against the same entity (`entity-id@1)`.
For more information about working with change sets, see [ Working with change sets].
[1]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_StartChangeSet.html#API_StartChangeSet_Examples [2]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets
723 724 725 726 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 723 def start_change_set(params = {}, = {}) req = build_request(:start_change_set, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
747 748 749 |
# File 'lib/aws-sdk-marketplacecatalog/client.rb', line 747 def waiter_names [] end |